React Starter Template
Description: Reactonite starter template page

# Reactonite

A transpiler to convert HTML to React code and PWAs ✨

Get Started!

## About Reactonite

Reactonite is a wrapper for React which allows one to write vanilla html code and convert it to a react code and hence building a PWA, SPA ✨
It facilitates one to transpile HTML code to React website, create PWAs and React applications as quickly as possible. Acting as a wrapper to NPM it helps you install dependencies and has functionality of Hot Reloading. It supports almost all HTML tags we have worked upon so far and is powered by React hooks as well. 😄

### Reactonite is Open Source!

Reactonite is a Free and Open Source, and it's source code is available to the community on our Github here. We believe in peer reviews and contribution for Reactonite to be of great success.

Interested in contributing to the project? Feel free to create a PR to on of the issues on Github or simply make one if you feel like so!

Contibuting Guide!

## Our Team

Although Reactonite is Open Source and each contribution is of great help!
Here's the core team behind Reactonite!

### Amogh Gulati

### Avi Garg

### Chirag Jain

### Aniket Pradhan

## Our Guides

Here's a special mentions to the those without whom Reactonite wouldn't have been possible.

### Pankaj Jalote

Distinguished Professor @ IIITD

### Saurabh Badhwar

Senior Software Engineer @ LinkedIn

## Get in touch

Feel free to reach us through this form, alternatively you can email any of the team members above.